'use client'

import React, { useEffect, useRef } from 'react'
import { motion, useAnimation, useInView } from 'framer-motion'

interface FeatureCardProps {
  number: string
  title: string
  description: string
}

const FeatureCard: React.FC<FeatureCardProps> = ({ number, title, description }) => {
  const controls = useAnimation()
  const ref = useRef(null)
  const isInView = useInView(ref, { once: true })

  useEffect(() => {
    if (isInView) {
      controls.start('visible')
    }
  }, [controls, isInView])

  return (
    <motion.div
      ref={ref}
      className="enf-card relative p-[2px] rounded-lg overflow-hidden"
      initial="hidden"
      animate={controls}
      variants={{
        hidden: { opacity: 0, y: 50 },
        visible: { opacity: 1, y: 0, transition: { duration: 0.5 } }
      }}
      whileHover={{ scale: 1.05, transition: { duration: 0.2 } }}
    >
      <div className="enf-card-border absolute inset-0 bg-gradient-to-r from-pink-500 via-purple-500 to-blue-500 opacity-75 animate-gradient-xy"></div>
      <div className="enf-card-content bg-gray-800 bg-opacity-95 p-6 rounded-lg relative z-10 h-full">
        <div className="enf-card-number text-gray-700 text-9xl font-bold absolute top-0 right-0 opacity-20">
          {number}
        </div>
        <h3 className="enf-card-title text-white text-2xl font-bold mb-4 relative z-10">{title}</h3>
        <p className="enf-card-description text-gray-300 relative z-10">{description}</p>
      </div>
    </motion.div>
  )
}

const ExploreNewFeatures: React.FC = () => {
  const controls = useAnimation()
  const ref = useRef(null)
  const isInView = useInView(ref, { once: true })

  useEffect(() => {
    if (isInView) {
      controls.start('visible')
    }
  }, [controls, isInView])

  return (
    <section className="enf-section bg-gray-900 py-16">
      <div className="enf-container max-w-6xl mx-auto px-4">
        <motion.h2
          className="enf-title text-5xl font-bold text-center mb-4 text-[#ff6b6b]"
          initial="hidden"
          animate={controls}
          variants={{
            hidden: { opacity: 0, y: -20 },
            visible: { opacity: 1, y: 0, transition: { duration: 0.5 } }
          }}
        >
          Explore New Features
        </motion.h2>
        <motion.p
          className="enf-subtitle text-xl text-center mb-12 text-gray-400"
          initial="hidden"
          animate={controls}
          variants={{
            hidden: { opacity: 0, y: -20 },
            visible: { opacity: 1, y: 0, transition: { duration: 0.5, delay: 0.2 } }
          }}
        >
          Learn about the latest innovations and improvements.
        </motion.p>
        <div className="enf-grid grid grid-cols-1 md:grid-cols-3 gap-8" ref={ref}>
          <FeatureCard
            number="01"
            title="Enhanced Performance"
            description="Discover how we've optimized speed and performance for all users."
          />
          <FeatureCard
            number="02"
            title="Mobile-First Design"
            description="Experience seamless usability across devices with our responsive design."
          />
          <FeatureCard
            number="03"
            title="Advanced Security"
            description="Your data and privacy are our top priority with the latest security protocols."
          />
        </div>
      </div>
    </section>
  )
}

export default ExploreNewFeatures